"""Package for management procedures as described in KNX-Standard 3.5.2."""
# flake8: noqa
from .management import Management, P2PConnection
